@@ -547,12 +547,15 @@ static int get_window_idx(struct pager *pager, int rx, int ry, int desk)
 		struct client_window *window = &pager->windows[i];
 		int w, h, sw, sh;
 
-		if (window->desk != desk && window->desk != -1)
+		if (!(window->desk == desk || (window->desk == -1 && pager->show_sticky)))
 			continue;
 
 		if (window->type == WINDOW_TYPE_DESKTOP)
 			continue;
 
+		if (window->states & WINDOW_STATE_HIDDEN)
+			continue;
+
 		h = window->h;
 		w = window->w;
 		if (window->states & WINDOW_STATE_SHADED)
